@@ -12,12 +12,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with TDC.  If not, see <http://www.gnu.org/licenses/>.
+ * along with TDC.  If not, see <https://www.gnu.org/licenses/>.
  *
- * Authors:      Michael Lustfield <mtecknology@ubuntu.com>
- * Contributors: Mikael Magnusson <mikachu@comhem.se>
- *               Dave Foster <daf@minuslab.net>
- *               Tom Cornall <t.cornall@gmail.com>
+ * Copyright: (C) Michael Lustfield <michael@lustfield.net>
  */
 
 #include <X11/Xlib.h>
@@ -102,7 +99,7 @@ void get_params(Display *display, int argc, char *argv[]) {
   if (!xdefaults) {
     die("Memory allocation failed");
   }
-  sprintf(xdefaults, "%s/.Xdefaults", getenv("HOME"));
+  snprintf(xdefaults, sizeof(xdefaults), "%s/.Xdefaults", getenv("HOME"));
   XrmCombineFileDatabase(xdefaults, &database, True);
   free(xdefaults);
 
@@ -141,7 +138,7 @@ void get_params(Display *display, int argc, char *argv[]) {
 
   /* check for version request */
   if (XrmGetResource(database, "tdc.version", "tdc.version", &type, &xrmval) == True) {
-    printf("tdc 1.4\n");
+    printf("tdc 1.6\n");
     exit(0);
   }
 
@@ -298,7 +295,7 @@ void get_calendar(char line[8][30], int month, int year) {
   char command[30];
   char buff[8][30];
 
-  sprintf(command, "cal -h %d %d", month, year);
+  snprintf(command, sizeof(command), "cal -h %d %d", month, year);
 
   fp = popen(command, "r");
   while (fgets(buff[i], sizeof buff[i], fp)) {
@@ -307,7 +304,7 @@ void get_calendar(char line[8][30], int month, int year) {
   pclose(fp);
 
   for (i = 0; i < 8; i++) {
-    sprintf(line[i], "%-30s", buff[i]);
+    snprintf(line[i], sizeof(line[i]), "%-30s", buff[i]);
   }
 }
 
@@ -319,7 +316,7 @@ void findtoday(int *todayi, int *todayj, int cal_m, int cal_y) {
   *todayj = -1;
 
   if (cal_m == getmonth() && cal_y == getyear()) {
-    sprintf(needle, "%d", getday());
+    snprintf(needle, sizeof(needle), "%d", getday());
 
     pos_h = (char*) &curr_cal[2];
     pos_n = (char*) strstr(curr_cal[2], needle);
@@ -355,7 +352,7 @@ void paintCalendar(Display *display, int cal_m, int cal_y, XftDraw *caldraw,
     for (j = 0; j < 20; j++) {
       p_x = j * glyph_w + 1;
       p_y = (i + 1) * glyph_h;
-      sprintf(buff, "%c", curr_cal[i][j]);
+      snprintf(buff, sizeof(buff), "%c", curr_cal[i][j]);
       if ((int) buff[0] != 10) {
         /*make sure not to print newline chars */
         if (i == todayi && (j == todayj || j == todayj + 1)) {
